Coverage report

# Coverage report: 56%

Module | statements | run | excluded | coverage
--- | --- | --- | --- | ---
pages.__init__ | 3 | 3 | 0 | 100%
pages.admin.__init__ | 201 | 131 | 0 | 65%
pages.admin.forms | 48 | 30 | 0 | 62%
pages.admin.utils | 35 | 34 | 0 | 97%
pages.admin.views | 60 | 23 | 0 | 38%
pages.widgets | 160 | 104 | 0 | 65%
pages.context_processors | 3 | 3 | 0 | 100%
pages.http | 76 | 60 | 0 | 79%
pages.managers | 168 | 42 | 0 | 25%
pages.migrations.0001_initial | 22 | 8 | 0 | 36%
pages.migrations.0002_add_frozen | 10 | 8 | 0 | 80%
pages.migrations.__init__ | 1 | 1 | 0 | 100%
pages.models | 211 | 99 | 0 | 47%
pages.settings | 39 | 34 | 0 | 87%
pages.templatetags.__init__ | 0 | 0 | 0 | 100%
pages.templatetags.pages_tags | 171 | 97 | 0 | 57%
pages.urlconf_registry | 27 | 21 | 0 | 78%
pages.urls | 9 | 8 | 0 | 89%
pages.utils | 102 | 57 | 0 | 56%
pages.views | 55 | 22 | 0 | 40%
pages.widgets_registry | 17 | 14 | 0 | 82%
Total | 1418 | 799 | 0 | 56%